@@ -31,9 +31,16 @@ from customers.models import Organization
 from commons.models import Person
 from corgy_common.models import gender_male,gender_female, gender_choices
 from commons.models import Address
-from masterdata.models import TimeSheet
-from masterdata.models import TimeSheetStatistic
-from masterdata.models import TimeSheetItem
+from labor.models import TimeSheet
+from labor.models import TimeSheetStatistic
+from labor.models import TimeSheetItem
+
+from labor.models import Employment
+from labor.models import Salary
+from labor.models import BankAccount
+from labor.models import Salary
+from labor.models import SalaryBlockingItem
+
 import calendar
 from random import choice, randint
 import json
@@ -106,6 +113,15 @@ class Command(BaseCommand):
 
     def handle(self, *args, **options):
 
+        TimeSheetItem.objects.all().delete()
+        TimeSheet.objects.all().delete()
+
+        BankAccount.objects.all().delete()
+        SalaryBlockingItem.objects.all().delete()
+
+        Salary.objects.all().delete()
+        Employment.objects.all().delete()
+
         Organization.objects.all().delete()
         Individual.objects.all().delete()
         Customer.objects.all().delete()
@@ -156,10 +172,14 @@ class Command(BaseCommand):
         self.generate_persons(firstnames=self.MALE_FIRST_NAMES, amount=20)
         self.generate_individuals(amount=15)
         self.generate_organizations(amount=7)
+        self.generate_bank_accounts(amount=5)
 
         self.stdout.write("Adatok generálása ... %s" % self.style.SUCCESS("OK"))
         self.log_pauses()
-        self.log_timesheets()
+
+
+        self.recruit()
+        self.pay_salaries()
 
     def create_family_tax_discount_statements(self):
         """
@@ -656,6 +676,17 @@ class Command(BaseCommand):
             self.style.SUCCESS("OK")
         ))
 
+    def generate_bank_accounts(self, amount=10):
+        for index in range(0, amount):
+            BankAccount.objects.create(
+                beneficiary='{name} Bank'.format(name=choice(self.FAMILY_NAMES)),
+                account_number='{first}-{second}-{third}'.format(
+                    first=randint(10000000, 99999999),
+                    second=randint(10000000, 99999999),
+                    third=randint(10000000, 99999999),
+                ),
+            )
+
     def generate_persons(self, firstnames=[], gender=gender_female, amount=10):
 
         for index in range(0, amount):
@@ -758,61 +789,80 @@ class Command(BaseCommand):
         Pause.objects.create(category=c41, begin=d_2020_01_15, end=d_2020_01_15)
         Pause.objects.create(category=c71, begin=d_2020_01_15, end=d_2020_01_29)
 
-    def log_timesheets(self):
+    def log_timesheets(self, salary: Salary, year: int, month: int):
+
+        sheet = TimeSheet.objects.create(current_year=year, current_month=month)
+        begin = datetime(year=year, month=month, day=1)
+        end = datetime(year=year, month=month, day=calendar.monthrange(year, month)[1])
+        for day in range(begin.day, end.day):
+            category = choice(TimeSheetCategory.objects.all())
+            time = timedelta(hours=randint(2, 12))
+            TimeSheetItem.objects.create(
+                category=category,
+                sheet=sheet,
+                timestamp=datetime(year=year, month=month, day=day),
+                duration=time
+            )
+        salary.timesheet = sheet
+        salary.save()
+
+        sheet.prepare()
+        sheet.summarize()
+
+    def recruit(self, headcount=10):
+        for head in range(1, headcount):
+            employee = choice(Person.objects.all())
+            employer = choice(Customer.objects.all())
+            aq = choice(ApplianceQuality.objects.all())
+            self._highlight(
+                message='{employee}-t foglalkoztatása, {employer} által ({type})',
+                employee=str(employee),
+                employer=str(employer),
+                type=str(aq)
+            )
+            Employment.objects.create(
+                employee=employee,
+                employer=employer,
+                type=aq,
+            )
 
 
-        cX = TimeSheetCategory.objects.get(code="X")
-        cF = TimeSheetCategory.objects.get(code="F")
-        cI = TimeSheetCategory.objects.get(code="I")
-        cS = TimeSheetCategory.objects.get(code="S")
+    def pay_salaries(self, minimum: int = 100000, maximum: int = 10000000, begin: datetime = datetime(year=2018, month=1, day=1), end: datetime = datetime.now()):
+        for employment in Employment.objects.all():
+            for year in range(begin.year, end.year):
+                for month in range(1, 12):
 
-        d_2020_06_01 = datetime(year=2020, month=6, day=1)
-        d_2020_06_02 = datetime(year=2020, month=6, day=2)
-        d_2020_06_03 = datetime(year=2020, month=6, day=3)
-        d_2020_06_04 = datetime(year=2020, month=6, day=4)
-        d_2020_06_05 = datetime(year=2020, month=6, day=5)
-        d_2020_06_06 = datetime(year=2020, month=6, day=6)
-        d_2020_06_07 = datetime(year=2020, month=6, day=7)
 
-        t1 = timedelta(hours=1)
-        t2 = timedelta(hours=2)
-        t4 = timedelta(hours=4)
-        t8 = timedelta(hours=8)
+                    day = calendar.monthrange(year, month)[1] - 1
+                    salary = randint(minimum, maximum)
+                    self._highlight(
+                        message = '{year}/{month}  {employer} -> {employee}: {salary} ({type})',
+                        employee = str(employment.employee),
+                        employer = str(employment.employer),
+                        salary = salary,
+                        type = str(employment.type),
+                        year = year,
+                        month = month,
+                    )
+                    s = Salary.objects.create(
+                        employee=employment,
+                        salary=salary,
+                        begin=datetime(year=year, month=month, day=1),
+                        end=datetime(year=year, month=month, day=day),
+                    )
 
-        sheet1 = TimeSheet.objects.create(current_year=2020, current_month=1)
-        sheet2 = TimeSheet.objects.create(current_year=2020, current_month=2)
-        sheet3 = TimeSheet.objects.create(current_year=2020, current_month=3)
-        sheet4 = TimeSheet.objects.create(current_year=2020, current_month=4)
-        sheet5 = TimeSheet.objects.create(current_year=2020, current_month=5)
-        sheet6 = TimeSheet.objects.create(current_year=2020, current_month=6)
+                    self.log_timesheets(salary=s,year=year, month=month)
+                    self.generate_blocked_salaries(salary=s)
 
-        TimeSheetItem.objects.create(category=cX, sheet=sheet1, timestamp=d_2020_06_01, duration=t1)
-        TimeSheetItem.objects.create(category=cX, sheet=sheet1, timestamp=d_2020_06_01, duration=t2)
-        TimeSheetItem.objects.create(category=cX, sheet=sheet1, timestamp=d_2020_06_01, duration=t4)
-        TimeSheetItem.objects.create(category=cX, sheet=sheet1, timestamp=d_2020_06_01, duration=t2)
-        TimeSheetItem.objects.create(category=cX, sheet=sheet1, timestamp=d_2020_06_01, duration=t4)
+    def generate_blocked_salaries(self, salary: Salary):
+        for b in range(0, randint(0, 10)):
+            SalaryBlockingItem.objects.create(
+                salary=salary,
+                value=randint(0, 100000),
+                account=choice(BankAccount.objects.all()),
+            )
 
-        TimeSheetItem.objects.create(category=cX, sheet=sheet2, timestamp=d_2020_06_01, duration=t8)
-        TimeSheetItem.objects.create(category=cX, sheet=sheet2, timestamp=d_2020_06_01, duration=t1)
-        TimeSheetItem.objects.create(category=cX, sheet=sheet2, timestamp=d_2020_06_01, duration=t1)
-        TimeSheetItem.objects.create(category=cX, sheet=sheet2, timestamp=d_2020_06_01, duration=t2)
-        TimeSheetItem.objects.create(category=cX, sheet=sheet2, timestamp=d_2020_06_01, duration=t2)
-        TimeSheetItem.objects.create(category=cX, sheet=sheet2, timestamp=d_2020_06_01, duration=t4)
-        TimeSheetItem.objects.create(category=cX, sheet=sheet2, timestamp=d_2020_06_01, duration=t1)
-        TimeSheetItem.objects.create(category=cX, sheet=sheet2, timestamp=d_2020_06_01, duration=t1)
-        TimeSheetItem.objects.create(category=cX, sheet=sheet2, timestamp=d_2020_06_01, duration=t1)
-        TimeSheetItem.objects.create(category=cX, sheet=sheet2, timestamp=d_2020_06_01, duration=t1)
-
-        TimeSheetItem.objects.create(category=cX, sheet=sheet3, timestamp=d_2020_06_01, duration=t1)
-        TimeSheetItem.objects.create(category=cX, sheet=sheet3, timestamp=d_2020_06_01, duration=t1)
-        TimeSheetItem.objects.create(category=cX, sheet=sheet3, timestamp=d_2020_06_01, duration=t1)
-        TimeSheetItem.objects.create(category=cX, sheet=sheet3, timestamp=d_2020_06_01, duration=t2)
-        TimeSheetItem.objects.create(category=cX, sheet=sheet3, timestamp=d_2020_06_01, duration=t8)
-        TimeSheetItem.objects.create(category=cX, sheet=sheet3, timestamp=d_2020_06_01, duration=t8)
-        TimeSheetItem.objects.create(category=cX, sheet=sheet3, timestamp=d_2020_06_01, duration=t8)
-        TimeSheetItem.objects.create(category=cX, sheet=sheet3, timestamp=d_2020_06_01, duration=t8)
-        TimeSheetItem.objects.create(category=cX, sheet=sheet3, timestamp=d_2020_06_01, duration=t1)
-        TimeSheetItem.objects.create(category=cX, sheet=sheet3, timestamp=d_2020_06_01, duration=t1)
-        TimeSheetItem.objects.create(category=cX, sheet=sheet3, timestamp=d_2020_06_01, duration=t1)
-        TimeSheetItem.objects.create(category=cX, sheet=sheet3, timestamp=d_2020_06_01, duration=t1)
-        TimeSheetItem.objects.create(category=cX, sheet=sheet3, timestamp=d_2020_06_01, duration=t1)
+    def _highlight(self, message: str, **kwargs):
+        self.stdout.write(message.format(
+            **kwargs
+        ))
\ No newline at end of file
